@@ -9,7 +9,8 @@ from hello.utils import importer
 
 import fiftyone as fo
 
-dataset_doc_str = """tips:
+dataset_doc_str = """\
+tips:
 
     <dataset_name>/
     ├── README.md  # 按照Markdown标准扩展信息
@@ -121,7 +122,7 @@ def load_text_dataset(info, data_path, labels_path, field_name):
 
 
 def _parse_text_line(line):
-    """
+    """\
     line format:
         filepath,height,width,x1,y1,x2,y2,confidence,label,x1,y1,x2,y2,confidence,label
     """
